@@ -50,7 +50,7 @@ class XMLIterator(TableIterator):
             elif isinstance(field, models.IntegerField):
                 value = int(value) if value else None
             else:
-                value = unescape(value).strip().replace('\n', ' ').replace('\r', ' ')
+                value = ' '.join(unescape(value).strip().replace('\n', ' ').replace('\r', ' ').split())
 
             yield key, value
 
